# **********************************************************************
#  Licensed Material - Property of IBM
#  5724-M24 
#  Copyright IBM Corp. 2007, 2011.  All rights reserved.
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# **********************************************************************
# Created: 10/28/2008
# 
import os, re
from java.lang import System
from java.text import SimpleDateFormat
from java.util import Date
lineSeparator = System.getProperty("line.separator")
from ivtout import outputResult,sectionBegin,sectionEnd
from com.ibm.wbmonitor.install.common.log import ILogger

#__all__ = []


class CheckWAS:

  className = "CheckWAS"

  def __init__(self, log, resolver):
     self.log   = log
     self.mesgResolver = resolver

  def checkWASStatus(self, checkWAS, logDir, profileType, serverName):
     errorCount = 1
     methodName = "checkWASStatus"
     if (checkWAS == "false"):
        return 0

     if (checkWAS == "failed"):
        mesgKey = "application.server.start.failed"
        if (profileType == 2):
           mesgKey = "deployment.manager.server.start.failed"
        mesgNL = self.mesgResolver.getMessage(mesgKey, [serverName])
        sectionBegin('component', {'title':mesgNL})
        sectionEnd(1)
        mesgNL = mesgNL + " Review the SystemOut.log and the SystemErr.log under " + logDir + " for more detailed information."
        self.log.msg(ILogger.TYPE_WARN, CheckWAS.className, methodName, mesgNL)
        return errorCount

     #check SystemErr
     #parser to convert time string to date object for comparing    
     parser = SimpleDateFormat("MM/dd/yyyy_HH:mm:ss:SSS_z")

     #get IVT start time in Date object
     ivtDate = parser.parse(checkWAS)

     sysErr = os.path.join(logDir, "SystemErr.log")
     fileSize = os.path.getsize(sysErr)
     if (fileSize == 0):
        return 0
     #This size should be enough to one java exception 
     sizeToRead = 16384
     offset = 0
     fileHandle = open(sysErr, 'r')
     if (fileSize > sizeToRead):
        offset = fileSize - sizeToRead
        fileHandle.seek(offset, 0)
     lines = fileHandle.readlines()
     fileHandle.close()
     linePattern = re.compile('^\[([\d]+)/([\d]+)/([\d]+) ([\d]+):([\d]+):([\d]+):([\d]+) ([^\]]+)\].*$')
     foundError = 0
     for line in lines:
       m = linePattern.search(line)
       if (m):
          timestamp = '%02d/%02d/20%02d_%02d:%02d:%02d:%03d_%s' % (m.group(1),m.group(2),m.group(3),m.group(4),m.group(5),m.group(6),m.group(7),m.group(8))
          thisDate = parser.parse(timestamp)
          if ((thisDate.compareTo(ivtDate) >= 0) and (line.find("R SLF4J:") < 0)):
             foundError = 1
             break

     if (not foundError):
        return 0

     #Found errors in SystemErr.log during IVT execution.
     mesgNL = self.mesgResolver.getMessage("found.system.error")
     sectionBegin('component', {'title':mesgNL})
     sectionEnd(1)
     mesgNL = mesgNL + " Review the SystemOut.log and the SystemErr.log under " + logDir + " for more detailed information."
     self.log.msg(ILogger.TYPE_WARN, CheckWAS.className, methodName, mesgNL)
     return errorCount
